Module path

Module path 

A structured path to a specific location in a schema. See the docs on Path.

Structs

ParseError

Enums

Path
A structured path to a specific location in a schema.
PathInArgument
PathInField
PathInType