pub enum Path<'a> {
SchemaDefinition,
SchemaExtension(usize),
TypeDefinition(&'a str, Option<PathInType<'a>>),
TypeExtension(&'a str, usize, Option<PathInType<'a>>),
DirectiveDefinition(&'a str),
}Expand description
A structured path to a specific location in a schema.
Paths have a structured string representation.
Each level in a path is separated by a ‘.’ character. Directive uses, type definition extensions and schema definition extensions have an index to distinguish between them. The index is optional.
First level:
- Type definitions are unprefixed.
- Type extensions have an index, for example
Query[3]. - Directive definitions are prefixed with an
@:@authorized. :schemafor schema definitions,:schema[1](index) for extensions.
Second level:
- Fields, union members, enum values and input object fields are unprefixed.
- Directives on types and schema definitions are prefixed with an
@and followed by an index:@key[0]. - Interface implementations are prefixed with an
&:&SomeInterface.
Third level:
- Field arguments are unprefixed.
- Directives on fields and enum values are prefixed with an
@and followed by an index:@include[0].
Variants
SchemaDefinition
SchemaExtension(usize)
TypeDefinition(&'a str, Option<PathInType<'a>>)
TypeExtension(&'a str, usize, Option<PathInType<'a>>)
DirectiveDefinition(&'a str)
Implementations