pub struct Change {
pub path: String,
pub kind: ChangeKind,
pub span: Span,
pub source_span: Option<Span>,
}Expand description
A change that represents a meaningful difference between the two schemas. Changes have a
direction: from source to target. For example, if kind is AddField, it means the field does
not exist in the source schema but it does exist in the target schema.
Fields
path: StringWhere the change happened in the schema. It is dot separated where relevant. For example if
the change happened in a field argument, the path will be something like
ParentTypeName.fieldName.argumentName.
See crate::path::Path for the full documentation.
kind: ChangeKindThe nature of the change.
span: SpanContents depend on the change kind:
- [ChangeQueryType]/[ChangeMutationType]/[ChangeSubscriptionType]: the new type
- [AddObjectType]/[AddUnion]/[AddEnum]/[AddScalar]/[AddInterface]/[AddInputObject]/[AddSchemaDefinition]/[AddDirectiveDefinition]: the whole definition.
- [AddInterfaceImplementation]/[RemoveInterfaceImplementation]: empty
- [ChangeFieldType]/[ChangeFieldArgumentType]: the new type
- [RemoveObjectType]/[RemoveField]/[RemoveUnion]/[RemoveUnionMember]/[RemoveEnum]/[RemoveScalar]/[RemoveInterface]/[RemoveDirectiveDefinition]/[RemoveSchemaDefinition]/[RemoveInputObject]/[RemoveFieldArgument]/[RemoveFieldArgumentDefault]: empty
- [AddField]: the whole field definition
- [AddUnionMember]: the union member added
- [AddEnumValue]/[RemoveEnumValue]: empty
- [AddFieldArgument]: the value of the argument, potentially with the default
- [AddFieldArgumentDefault]/[ChangeFieldArgumentDefault]: the default value of the argument
- [ChangeDescription]: the new description, or empty if the description was removed
source_span: Option<Span>The span of the corresponding content in the source schema, when there is meaningful
content there to point to. None otherwise, in particular for change kinds where the item
only exists in the target schema (e.g. [AddField]) or carries no content on either side
(e.g. [AddInterfaceImplementation]/[RemoveInterfaceImplementation]).
Currently populated for:
- [ChangeFieldType]/[ChangeFieldArgumentType]: the old type
- [ChangeFieldArgumentDefault]: the old default value of the argument
- [ChangeDescription]: the old description, or
Noneif the description was added - [RemoveField]/[RemoveEnumValue]/[RemoveUnionMember]: the removed field/value/member
- [RemoveFieldArgument]: the removed argument
- [RemoveFieldArgumentDefault]: the removed default value of the argument
- [RemoveSchemaDefinition]: the removed schema definition
- [RemoveDirective]: the removed directive usage