A structured path to a specific location in a schema. See the docs on Path.
Structs
Enums
- Path
- A structured path to a specific location in a schema.
- Path
InArgument - Path
InField - Path
InType
A structured path to a specific location in a schema. See the docs on Path.