pub struct Change {
pub path: String,
pub kind: ChangeKind,
pub span: Span,
}Expand description
A change that represents a meaningful difference between the two schemas. Changes have a
direction: from source to target. For example, if kind is AddField, it means the field does
not exist in the source schema but it does exist in the target schema.
Fields
path: StringWhere the change happened in the schema. It is dot separated where relevant. For example if
the change happened in a field argument, the path will be something like
ParentTypeName.fieldName.argumentName.
See crate::path::Path for the full documentation.
kind: ChangeKindThe nature of the change.
span: SpanContents depend on the change kind:
- [ChangeQueryType]/[ChangeMutationType]/[ChangeSubscriptionType]: the new type
- [AddObjectType]/[AddUnion]/[AddEnum]/[AddScalar]/[AddInterface]/[AddInputObject]/[AddSchemaDefinition]/[AddDirectiveDefinition]: the whole definition.
- [AddInterfaceImplementation]/[RemoveInterfaceImplementation]: empty
- [ChangeFieldType]/[ChangeFieldArgumentType]: the new type
- [RemoveObjectType]/[RemoveField]/[RemoveUnion]/[RemoveUnionMember]/[RemoveEnum]/[RemoveScalar]/[RemoveInterface]/[RemoveDirectiveDefinition]/[RemoveSchemaDefinition]/[RemoveInputObject]/[RemoveFieldArgument]/[RemoveFieldArgumentDefault]: empty
- [AddField]: the whole field definition
- [AddUnionMember]: the union member added
- [AddEnumValue]/[RemoveEnumValue]: empty
- [AddFieldArgument]: the value of the argument, potentially with the default
- [AddFieldArgumentDefault]/[ChangeFieldArgumentDefault]: the default value of the argument